of property
How many the run started with, so the spent ones can be drawn dim. Null draws only what is left.
Implementation
final int? of;
How many the run started with, so the spent ones can be drawn dim. Null draws only what is left.
final int? of;